@@ -77,6 +77,7 @@ static EMC_IO_STAT emcioStatus;
 static NML *emcErrorBuffer = 0;
 
 static char *ttcomments[CANON_POCKETS_MAX];
+static int fms[CANON_POCKETS_MAX];
 static int random_toolchanger = 0;
 
 
@@ -250,6 +251,71 @@ static int iniLoad(const char *filename)
     return 0;
 }
 
+/********************************************************************
+*
+* Description: saveToolTable(const char *filename, CANON_TOOL_TABLE toolTable[])
+*		Saves the tool table from toolTable[] array into file filename.
+*		  Array is CANON_TOOL_MAX + 1 entries, since 0 is included.
+*
+* Return Value: Zero on success or -1 if file not found.
+*
+* Side Effects: Default setting used if the parameter not found in
+*		the ini file.
+*
+* Called By: main()
+*
+********************************************************************/
+static int saveToolTable(const char *filename,
+			 CANON_TOOL_TABLE toolTable[])
+{
+    int pocket;
+    FILE *fp;
+    const char *name;
+    int start_pocket;
+
+    // check filename
+    if (filename[0] == 0) {
+	name = tool_table_file;
+    } else {
+	// point to name provided
+	name = filename;
+    }
+
+    // open tool table file
+    if (NULL == (fp = fopen(name, "w"))) {
+	// can't open file
+	return -1;
+    }
+
+    if(random_toolchanger) {
+        start_pocket = 0;
+    } else {
+        start_pocket = 1;
+    }
+    for (pocket = start_pocket; pocket < CANON_POCKETS_MAX; pocket++) {
+        if (toolTable[pocket].toolno != -1) {
+            fprintf(fp, "T%d P%d", toolTable[pocket].toolno, random_toolchanger? pocket: fms[pocket]);
+            if (toolTable[pocket].diameter) fprintf(fp, " D%f", toolTable[pocket].diameter);
+            if (toolTable[pocket].offset.tran.x) fprintf(fp, " X%+f", toolTable[pocket].offset.tran.x);
+            if (toolTable[pocket].offset.tran.y) fprintf(fp, " Y%+f", toolTable[pocket].offset.tran.y);
+            if (toolTable[pocket].offset.tran.z) fprintf(fp, " Z%+f", toolTable[pocket].offset.tran.z);
+            if (toolTable[pocket].offset.a) fprintf(fp, " A%+f", toolTable[pocket].offset.a);
+            if (toolTable[pocket].offset.b) fprintf(fp, " B%+f", toolTable[pocket].offset.b);
+            if (toolTable[pocket].offset.c) fprintf(fp, " C%+f", toolTable[pocket].offset.c);
+            if (toolTable[pocket].offset.u) fprintf(fp, " U%+f", toolTable[pocket].offset.u);
+            if (toolTable[pocket].offset.v) fprintf(fp, " V%+f", toolTable[pocket].offset.v);
+            if (toolTable[pocket].offset.w) fprintf(fp, " W%+f", toolTable[pocket].offset.w);
+            if (toolTable[pocket].frontangle) fprintf(fp, " I%+f", toolTable[pocket].frontangle);
+            if (toolTable[pocket].backangle) fprintf(fp, " J%+f", toolTable[pocket].backangle);
+            if (toolTable[pocket].orientation) fprintf(fp, " Q%d", toolTable[pocket].orientation);
+            fprintf(fp, " ;%s\n", ttcomments[pocket]);
+        }
+    }
+
+    fclose(fp);
+    return 0;
+}
+
 static int done = 0;
 
 /********************************************************************
@@ -536,7 +602,7 @@ void load_tool(int pocket) {
         ttcomments[0] = ttcomments[pocket];
         ttcomments[pocket] = comment_temp;
 
-        if (0 != saveToolTable(tool_table_file, emcioStatus.tool.toolTable, ttcomments, random_toolchanger))
+        if (0 != saveToolTable(tool_table_file, emcioStatus.tool.toolTable))
             emcioStatus.status = RCS_ERROR;
     } else if(pocket == 0) {
         // on non-random tool-changers, asking for pocket 0 is the secret
@@ -693,11 +759,12 @@ int main(int argc, char *argv[])
         emcioStatus.tool.toolTable[0].frontangle = 0.0;
         emcioStatus.tool.toolTable[0].backangle = 0.0;
         emcioStatus.tool.toolTable[0].orientation = 0;
+        fms[0] = 0;
         ttcomments[0][0] = '\0';
     }
 
     if (0 != loadToolTable(tool_table_file, emcioStatus.tool.toolTable,
-		ttcomments, random_toolchanger)) {
+		fms, ttcomments, random_toolchanger)) {
 	rcs_print_error("can't load tool table.\n");
     }
 
@@ -771,7 +838,7 @@ int main(int argc, char *argv[])
 	case EMC_TOOL_INIT_TYPE:
 	    rtapi_print_msg(RTAPI_MSG_DBG, "EMC_TOOL_INIT\n");
 	    loadToolTable(tool_table_file, emcioStatus.tool.toolTable,
-		    ttcomments, random_toolchanger);
+		    fms, ttcomments, random_toolchanger);
 	    reload_tool_number(emcioStatus.tool.toolInSpindle);
 	    break;
 
@@ -794,15 +861,14 @@ int main(int argc, char *argv[])
 	case EMC_TOOL_PREPARE_TYPE:
             {
                 signed int p = ((EMC_TOOL_PREPARE*)emcioCommand)->pocket;
-                int t = ((EMC_TOOL_PREPARE*)emcioCommand)->tool;
+		int t = ((EMC_TOOL_PREPARE*)emcioCommand)->tool;
                 rtapi_print_msg(RTAPI_MSG_DBG, "EMC_TOOL_PREPARE tool=%d pocket=%d\n", t, p);
 
                 // Set HAL pins/params for tool number, pocket, and index.
                 iocontrol_data->tool_prep_index = p;
-                *(iocontrol_data->tool_prep_pocket) = random_toolchanger? p: emcioStatus.tool.toolTable[p].pocketno;
-                if(!random_toolchanger && p == 0) {//unload spindle
+                *(iocontrol_data->tool_prep_pocket) = random_toolchanger? p: fms[p];
+                if(!random_toolchanger && p == 0) {
                     *(iocontrol_data->tool_prep_number) = 0;
-					*(iocontrol_data->tool_prep_pocket) = 0;
                 } else {
                     *(iocontrol_data->tool_prep_number) = emcioStatus.tool.toolTable[p].toolno;
                 }
@@ -861,7 +927,7 @@ int main(int argc, char *argv[])
 		if(!strlen(filename)) filename = tool_table_file;
 		rtapi_print_msg(RTAPI_MSG_DBG, "EMC_TOOL_LOAD_TOOL_TABLE\n");
 		if (0 != loadToolTable(filename, emcioStatus.tool.toolTable,
-				  ttcomments, random_toolchanger))
+				  fms, ttcomments, random_toolchanger))
 		    emcioStatus.status = RCS_ERROR;
 		else
 		    reload_tool_number(emcioStatus.tool.toolInSpindle);
@@ -898,7 +964,7 @@ int main(int argc, char *argv[])
                     emcioStatus.tool.toolTable[0] = emcioStatus.tool.toolTable[p];
                 }                    
             }
-	    if (0 != saveToolTable(tool_table_file, emcioStatus.tool.toolTable, ttcomments, random_toolchanger))
+	    if (0 != saveToolTable(tool_table_file, emcioStatus.tool.toolTable))
 		emcioStatus.status = RCS_ERROR;
 	    break;
 
