@@ -57,11 +57,7 @@ int mot_comp_id;
 emcmot_joint_t joint_array[EMCMOT_MAX_JOINTS];
 int num_joints = EMCMOT_MAX_JOINTS;
 emcmot_joint_t *joints = 0;
-int num_spindles = EMCMOT_MAX_SPINDLES;
 
-emcmot_axis_t axis_array[EMCMOT_MAX_AXIS];
-int num_axes = EMCMOT_MAX_AXIS;
-emcmot_axis_t *axes = 0;
 
 void emcmot_config_change(void) {
     if (emcmotConfig->head == emcmotConfig->tail) {
@@ -74,9 +70,8 @@ void emcmot_config_change(void) {
 
 
 static int init_comm_buffers(void) {
-    int joint_num, axis_num, n;
+    int joint_num, n;
     emcmot_joint_t *joint;
-    emcmot_axis_t *axis;
     int retval;
     int shmem_id;
 
@@ -115,21 +110,20 @@ static int init_comm_buffers(void) {
     emcmotError = &emcmotStruct->error;
 
     emcmotConfig->numJoints = num_joints;
-    emcmotConfig->numSpindles = num_spindles;
 
     emcmotStatus->vel = DEFAULT_VELOCITY;
     emcmotConfig->limitVel = DEFAULT_VELOCITY;
     emcmotStatus->acc = DEFAULT_ACCELERATION;
     emcmotStatus->feed_scale = 1.0;
     emcmotStatus->rapid_scale = 1.0;
-    for (int n = 0; n < EMCMOT_MAX_SPINDLES; n++) emcmotStatus->spindle_status[n].scale = 1.0;
+    emcmotStatus->spindle_scale = 1.0;
     emcmotStatus->net_feed_scale = 1.0;
     /* adaptive feed is off by default, feed override, spindle 
        override, and feed hold are on */
     emcmotStatus->enables_new = FS_ENABLED | SS_ENABLED | FH_ENABLED;
     emcmotStatus->enables_queued = emcmotStatus->enables_new;
     SET_MOTION_INPOS_FLAG(1);
-    emcmotConfig->kinType = KINEMATICS_IDENTITY;
+    emcmotConfig->kinematics_type = KINEMATICS_IDENTITY;
 
     emcmot_config_change();
 
@@ -149,6 +143,8 @@ static int init_comm_buffers(void) {
 	joint->acc_limit = 1.0;
 	joint->min_ferror = 0.01;
 	joint->max_ferror = 1.0;
+	joint->home_final_vel = -1;
+	joint->home_sequence = -1;
 
 	joint->comp.entry = &(joint->comp.array[0]);
 	/* the compensation code has -DBL_MAX at one end of the table
@@ -176,25 +172,6 @@ static int init_comm_buffers(void) {
 	SET_JOINT_INPOS_FLAG(joint, 1);
     }
 
-    /* init pointer to axes structs */
-    axes = axis_array;
-
-    /* init per-axis stuff */
-    for (axis_num = 0; axis_num < num_axes; axis_num++) {
-	/* point to structure for this axis */
-	axis = &axes[axis_num];
-	axis->pos_cmd = 0.0;
-	axis->teleop_vel_cmd = 0.0;
-	axis->max_pos_limit = 1.0;
-	axis->min_pos_limit = -1.0;
-	axis->vel_limit = 1.0;
-	axis->acc_limit = 1.0;
-	//simple_tp_t teleop_tp
-	axis->old_ajog_counts = 0;
-	axis->kb_ajog_active = 0;
-	axis->wheel_ajog_active = 0;
-    }
-
     emcmotDebug->start_time = time(NULL);
 
     rtapi_print_msg(RTAPI_MSG_INFO, "MOTION: init_comm_buffers() complete\n");
@@ -229,7 +206,6 @@ void update_joint_status(void) {
 	joint_status->pos_cmd = joint->pos_cmd;
 	joint_status->pos_fb = joint->pos_fb;
 	joint_status->vel_cmd = joint->vel_cmd;
-	joint_status->acc_cmd = joint->acc_cmd;
 	joint_status->ferror = joint->ferror;
 	joint_status->ferror_high_mark = joint->ferror_high_mark;
 	joint_status->backlash = joint->backlash;
@@ -237,17 +213,20 @@ void update_joint_status(void) {
 	joint_status->min_pos_limit = joint->min_pos_limit;
 	joint_status->min_ferror = joint->min_ferror;
 	joint_status->max_ferror = joint->max_ferror;
+	joint_status->home_offset = joint->home_offset;
     }
 }
 
 
 static void mark_joint_homed(int joint_num) {
-    emcmot_joint_status_t *joint_status;
+    emcmot_joint_t *joint;
 
-    joint_status = &emcmotStatus->joint_status[joint_num];
-    joint_status->homing = 0;
-    joint_status->homed  = 1;
-    return;
+    joint = &joints[joint_num];
+
+    SET_JOINT_HOMING_FLAG(joint, 0);
+    SET_JOINT_HOMED_FLAG(joint, 1);
+    SET_JOINT_AT_HOME_FLAG(joint, 1);
+    joint->home_state = HOME_IDLE;
 }
 
 void maybe_reopen_logfile() {
@@ -329,8 +308,8 @@ int main(int argc, char* argv[]) {
                 log_print("ABORT\n");
                 break;
 
-            case EMCMOT_JOINT_ABORT:
-                log_print("JOINT_ABORT joint=%d\n", c->joint);
+            case EMCMOT_AXIS_ABORT:
+                log_print("AXIS_ABORT joint=%d\n", c->axis);
                 break;
 
             case EMCMOT_ENABLE:
@@ -345,11 +324,11 @@ int main(int argc, char* argv[]) {
                 update_motion_state();
                 break;
 
-            case EMCMOT_JOINT_ENABLE_AMPLIFIER:
+            case EMCMOT_ENABLE_AMPLIFIER:
                 log_print("ENABLE_AMPLIFIER\n");
                 break;
 
-            case EMCMOT_JOINT_DISABLE_AMPLIFIER:
+            case EMCMOT_DISABLE_AMPLIFIER:
                 log_print("DISABLE_AMPLIFIER\n");
                 break;
 
@@ -361,12 +340,12 @@ int main(int argc, char* argv[]) {
                 log_print("DISABLE_WATCHDOG\n");
                 break;
 
-            case EMCMOT_JOINT_ACTIVATE:
-                log_print("JOINT_ACTIVATE joint=%d\n", c->joint);
+            case EMCMOT_ACTIVATE_JOINT:
+                log_print("ACTIVATE_JOINT joint=%d\n", c->axis);
                 break;
 
-            case EMCMOT_JOINT_DEACTIVATE:
-                log_print("JOINT_DEACTIVATE joint=%d\n", c->joint);
+            case EMCMOT_DEACTIVATE_JOINT:
+                log_print("DEACTIVATE_JOINT joint=%d\n", c->axis);
                 break;
 
             case EMCMOT_PAUSE:
@@ -435,19 +414,19 @@ int main(int argc, char* argv[]) {
                 log_print("OVERRIDE_LIMITS\n");
                 break;
 
-            case EMCMOT_JOINT_HOME:
-                log_print("JOINT_HOME joint=%d\n", c->joint);
-                if (c->joint < 0) {
+            case EMCMOT_HOME:
+                log_print("HOME joint=%d\n", c->axis);
+                if (c->axis < 0) {
                     for (int j = 0; j < num_joints; j ++) {
                         mark_joint_homed(j);
                     }
                 } else {
-                    mark_joint_homed(c->joint);
+                    mark_joint_homed(c->axis);
                 }
                 break;
 
-            case EMCMOT_JOINT_UNHOME:
-                log_print("JOINT_UNHOME joint=%d\n", c->joint);
+            case EMCMOT_UNHOME:
+                log_print("UNHOME joint=%d\n", c->axis);
                 break;
 
             case EMCMOT_JOG_CONT:
@@ -507,42 +486,25 @@ int main(int argc, char* argv[]) {
                 log_print("RIGID_TAP\n");
                 break;
 
-            case EMCMOT_SET_JOINT_POSITION_LIMITS:
+            case EMCMOT_SET_POSITION_LIMITS:
                 log_print(
-                    "SET_JOINT_POSITION_LIMITS joint=%d, min=%.6f, max=%.6f\n",
-                    c->joint, c->minLimit, c->maxLimit
-                );
-                joints[c->joint].max_pos_limit = c->maxLimit;
-                joints[c->joint].min_pos_limit = c->minLimit;
-                break;
-
-            case EMCMOT_SET_AXIS_POSITION_LIMITS:
-                log_print(
-                    "SET_AXIS_POSITION_LIMITS axis=%d, min=%.6f, max=%.6f\n",
+                    "SET_POSITION_LIMITS joint=%d, min=%.6f, max=%.6f\n",
                     c->axis, c->minLimit, c->maxLimit
                 );
-                axes[c->axis].max_pos_limit = c->maxLimit;
-                axes[c->axis].min_pos_limit = c->minLimit;
+                joints[c->axis].max_pos_limit = c->maxLimit;
+                joints[c->axis].min_pos_limit = c->minLimit;
                 break;
 
-            case EMCMOT_SET_AXIS_LOCKING_JOINT:
-                log_print(
-                    "SET_AXIS_LOCKING_JOINT axis=%d, locking_joint=%d\n",
-                    c->axis, c->joint
-                );
-                axes[c->axis].locking_joint = c->joint;
+            case EMCMOT_SET_BACKLASH:
+                log_print("SET_BACKLASH joint=%d, backlash=%.6f\n", c->axis, c->backlash);
                 break;
 
-            case EMCMOT_SET_JOINT_BACKLASH:
-                log_print("SET_JOINT_BACKLASH joint=%d, backlash=%.6f\n", c->joint, c->backlash);
+            case EMCMOT_SET_MIN_FERROR:
+                log_print("SET_MIN_FERROR joint=%d, minFerror=%.6f\n", c->axis, c->minFerror);
                 break;
 
-            case EMCMOT_SET_JOINT_MIN_FERROR:
-                log_print("SET_JOINT_MIN_FERROR joint=%d, minFerror=%.6f\n", c->joint, c->minFerror);
-                break;
-
-            case EMCMOT_SET_JOINT_MAX_FERROR:
-                log_print("SET_JOINT_MAX_FERROR joint=%d, maxFerror=%.6f\n", c->joint, c->maxFerror);
+            case EMCMOT_SET_MAX_FERROR:
+                log_print("SET_MAX_FERROR joint=%d, maxFerror=%.6f\n", c->axis, c->maxFerror);
                 break;
 
             case EMCMOT_SET_VEL:
@@ -553,20 +515,12 @@ int main(int argc, char* argv[]) {
                 log_print("SET_VEL_LIMIT vel=%.6f\n", c->vel);
                 break;
 
-            case EMCMOT_SET_AXIS_VEL_LIMIT:
-                log_print("SET_AXIS_VEL_LIMIT axis=%d vel=%.6f\n", c->axis, c->vel);
-                break;
-
             case EMCMOT_SET_JOINT_VEL_LIMIT:
-                log_print("SET_JOINT_VEL_LIMIT joint=%d, vel=%.6f\n", c->joint, c->vel);
-                break;
-
-            case EMCMOT_SET_AXIS_ACC_LIMIT:
-                log_print("SET_AXIS_ACC_LIMIT axis=%d, acc=%.6f\n", c->axis, c->acc);
+                log_print("SET_JOINT_VEL_LIMIT joint=%d, vel=%.6f\n", c->axis, c->vel);
                 break;
 
             case EMCMOT_SET_JOINT_ACC_LIMIT:
-                log_print("SET_JOINT_ACC_LIMIT joint=%d, acc=%.6f\n", c->joint, c->acc);
+                log_print("SET_JOINT_ACC_LIMIT joint=%d, acc=%.6f\n", c->axis, c->acc);
                 break;
 
             case EMCMOT_SET_ACC:
@@ -577,14 +531,9 @@ int main(int argc, char* argv[]) {
                 log_print("SET_TERM_COND termCond=%d, tolerance=%.6f\n", c->termCond, c->tolerance);
                 break;
 
-            case EMCMOT_SET_NUM_JOINTS:
-                log_print("SET_NUM_JOINTS %d\n", c->joint);
-                num_joints = c->joint;
-                break;
-
-            case EMCMOT_SET_NUM_SPINDLES:
-                log_print("SET_NUM_SPINDLES %d\n", c->spindle);
-                num_spindles = c->spindle;
+            case EMCMOT_SET_NUM_AXES:
+                log_print("SET_NUM_AXES %d\n", c->axis);
+                num_joints = c->axis;
                 break;
 
             case EMCMOT_SET_WORLD_HOME:
@@ -596,22 +545,15 @@ int main(int argc, char* argv[]) {
                 );
                 break;
 
-            case EMCMOT_SET_JOINT_HOMING_PARAMS:
+            case EMCMOT_SET_HOMING_PARAMS:
                 log_print(
-                    "SET_JOINT_HOMING_PARAMS joint=%d, offset=%.6f home=%.6f, final_vel=%.6f, search_vel=%.6f, latch_vel=%.6f, flags=0x%08x, sequence=%d, volatile=%d\n",
-                    c->joint, c->offset, c->home, c->home_final_vel,
+                    "SET_HOMING_PARAMS joint=%d, offset=%.6f home=%.6f, final_vel=%.6f, search_vel=%.6f, latch_vel=%.6f, flags=0x%08x, sequence=%d, volatile=%d\n",
+                    c->axis, c->offset, c->home, c->home_final_vel,
                     c->search_vel, c->latch_vel, c->flags,
                     c->home_sequence, c->volatile_home
                 );
                 break;
 
-            case EMCMOT_UPDATE_JOINT_HOMING_PARAMS:
-                log_print(
-                    "UPDATE_JOINT_HOMING_PARAMS joint=%d, offset=%.6f home=%.6f home_sequence=%d\n",
-                    c->joint, c->offset, c->home, c->home_sequence
-                );
-                break;
-
             case EMCMOT_SET_DEBUG:
                 log_print("SET_DEBUG\n");
                 break;
@@ -630,12 +572,12 @@ int main(int argc, char* argv[]) {
 
             case EMCMOT_SPINDLE_ON:
                 log_print("SPINDLE_ON speed=%f, css_factor=%f, xoffset=%f\n", c->vel, c->ini_maxvel, c->acc);
-                emcmotStatus->spindle_status[0].speed = c->vel;
+                emcmotStatus->spindle.speed = c->vel;
                 break;
 
             case EMCMOT_SPINDLE_OFF:
                 log_print("SPINDLE_OFF\n");
-                emcmotStatus->spindle_status[0].speed = 0;
+                emcmotStatus->spindle.speed = 0;
                 break;
 
             case EMCMOT_SPINDLE_INCREASE:
@@ -658,8 +600,8 @@ int main(int argc, char* argv[]) {
                 log_print("SPINDLE_ORIENT\n");
                 break;
 
-            case EMCMOT_SET_JOINT_MOTOR_OFFSET:
-                log_print("SET_JOINT_MOTOR_OFFSET\n");
+            case EMCMOT_SET_MOTOR_OFFSET:
+                log_print("SET_MOTOR_OFFSET\n");
                 break;
 
             case EMCMOT_SET_JOINT_COMP:
@@ -683,13 +625,6 @@ int main(int argc, char* argv[]) {
                 log_print("SETUP_ARC_BLENDS\n");
                 break;
 
-            case EMCMOT_SET_PROBE_ERR_INHIBIT:
-                log_print("SETUP_SET_PROBE_ERR_INHIBIT %d %d\n",
-                          c->probe_jog_err_inhibit,
-                          c->probe_home_err_inhibit);
-                break;
-
-
             default:
                 log_print("ERROR: unknown command %d\n", c->command);
                 break;
