@@ -12,7 +12,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #ifndef EMCTOOL_H
 #define EMCTOOL_H
@@ -25,7 +25,6 @@
 
 struct CANON_TOOL_TABLE {
     int toolno;
-    int pocketno;
     EmcPose offset;
     double diameter;
     double frontangle;
