@@ -14,7 +14,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <Python.h>
 #include <structmember.h>
@@ -145,10 +145,11 @@ static double _pos_x, _pos_y, _pos_z, _pos_a, _pos_b, _pos_c, _pos_u, _pos_v, _p
 EmcPose tool_offset;
 
 static InterpBase *pinterp;
+#define interp_new (*pinterp)
 
 #define callmethod(o, m, f, ...) PyObject_CallMethod((o), (char*)(m), (char*)(f), ## __VA_ARGS__)
 
-static void maybe_new_line(int sequence_number=pinterp->sequence_number());
+static void maybe_new_line(int sequence_number=interp_new.sequence_number());
 static void maybe_new_line(int sequence_number) {
     if(!pinterp) return;
     if(interp_error) return;
@@ -156,9 +157,9 @@ static void maybe_new_line(int sequence_number) {
         return;
     LineCode *new_line_code =
         (LineCode*)(PyObject_New(LineCode, &LineCodeType));
-    pinterp->active_settings(new_line_code->settings);
-    pinterp->active_g_codes(new_line_code->gcodes);
-    pinterp->active_m_codes(new_line_code->mcodes);
+    interp_new.active_settings(new_line_code->settings);
+    interp_new.active_g_codes(new_line_code->gcodes);
+    interp_new.active_m_codes(new_line_code->mcodes);
     new_line_code->gcodes[0] = sequence_number;
     last_sequence_number = sequence_number;
     PyObject *result = 
@@ -304,7 +305,7 @@ void SET_TRAVERSE_RATE(double rate) {
     Py_XDECREF(result);
 }
 
-void SET_FEED_MODE(int spindle, int mode) {
+void SET_FEED_MODE(int mode) {
 #if 0
     maybe_new_line();   
     if(interp_error) return;
@@ -398,15 +399,15 @@ void SET_CUTTER_RADIUS_COMPENSATION(double radius) {}
 void START_CUTTER_RADIUS_COMPENSATION(int direction) {}
 void STOP_CUTTER_RADIUS_COMPENSATION(int direction) {}
 void START_SPEED_FEED_SYNCH() {}
-void START_SPEED_FEED_SYNCH(int spindle, double sync, bool vel) {}
+void START_SPEED_FEED_SYNCH(double sync, bool vel) {}
 void STOP_SPEED_FEED_SYNCH() {}
-void START_SPINDLE_COUNTERCLOCKWISE(int spindle, int wait_for_at_speed) {}
-void START_SPINDLE_CLOCKWISE(int spindle, int wait_for_at_speed) {}
-void SET_SPINDLE_MODE(int spindle, double) {}
-void STOP_SPINDLE_TURNING(int spindle) {}
-void SET_SPINDLE_SPEED(int spindle, double rpm) {}
-void ORIENT_SPINDLE(int spindle, double d, int i) {}
-void WAIT_SPINDLE_ORIENT_COMPLETE(int s, double timeout) {}
+void START_SPINDLE_COUNTERCLOCKWISE() {}
+void START_SPINDLE_CLOCKWISE() {}
+void SET_SPINDLE_MODE(double) {}
+void STOP_SPINDLE_TURNING() {}
+void SET_SPINDLE_SPEED(double rpm) {}
+void ORIENT_SPINDLE(double d, int i) {}
+void WAIT_SPINDLE_ORIENT_COMPLETE(double timeout) {}
 void PROGRAM_STOP() {}
 void PROGRAM_END() {}
 void FINISH() {}
@@ -446,9 +447,9 @@ void SET_BLOCK_DELETE(bool enabled) {}
 void DISABLE_FEED_OVERRIDE() {}
 void DISABLE_FEED_HOLD() {}
 void ENABLE_FEED_HOLD() {}
-void DISABLE_SPEED_OVERRIDE(int spindle) {}
+void DISABLE_SPEED_OVERRIDE() {}
 void ENABLE_FEED_OVERRIDE() {}
-void ENABLE_SPEED_OVERRIDE(int spindle) {}
+void ENABLE_SPEED_OVERRIDE() {}
 void MIST_OFF() {}
 void FLOOD_OFF() {}
 void MIST_ON() {}
@@ -461,8 +462,8 @@ void SET_MOTION_OUTPUT_BIT(int bit) {}
 void SET_MOTION_OUTPUT_VALUE(int index, double value) {}
 void TURN_PROBE_ON() {}
 void TURN_PROBE_OFF() {}
-int UNLOCK_ROTARY(int line_no, int joint_num) {return 0;}
-int LOCK_ROTARY(int line_no, int joint_num) {return 0;}
+int UNLOCK_ROTARY(int line_no, int axis) {return 0;}
+int LOCK_ROTARY(int line_no, int axis) {return 0;}
 void INTERP_ABORT(int reason,const char *message) {}
 void PLUGIN_CALL(int len, const char *call) {}
 void IO_PLUGIN_CALL(int len, const char *call) {}
@@ -485,7 +486,7 @@ void STRAIGHT_PROBE(int line_number,
 
 }
 void RIGID_TAP(int line_number,
-               double x, double y, double z, double scale) {
+               double x, double y, double z) {
     if(metric) { x /= 25.4; y /= 25.4; z /= 25.4; }
     maybe_new_line(line_number);
     if(interp_error) return;
@@ -517,12 +518,6 @@ double GET_EXTERNAL_POSITION_U() { return _pos_u; }
 double GET_EXTERNAL_POSITION_V() { return _pos_v; }
 double GET_EXTERNAL_POSITION_W() { return _pos_w; }
 void INIT_CANON() {}
-
-void SET_PARAMETER_FILE_NAME(const char *name)
-{
-  strncpy(_parameter_file_name, name, PARAMETER_FILE_NAME_LENGTH);
-}
-
 void GET_EXTERNAL_PARAMETER_FILE_NAME(char *name, int max_size) {
     PyObject *result = PyObject_GetAttrString(callback, "parameter_file");
     if(!result) { name[0] = 0; return; }
@@ -531,9 +526,9 @@ void GET_EXTERNAL_PARAMETER_FILE_NAME(char *name, int max_size) {
     memset(name, 0, max_size);
     strncpy(name, s, max_size - 1);
 }
-CANON_UNITS GET_EXTERNAL_LENGTH_UNIT_TYPE() { return CANON_UNITS_INCHES; }
+int GET_EXTERNAL_LENGTH_UNIT_TYPE() { return CANON_UNITS_INCHES; }
 CANON_TOOL_TABLE GET_EXTERNAL_TOOL_TABLE(int pocket) {
-    CANON_TOOL_TABLE t = {-1,-1,{{0,0,0},0,0,0,0,0,0},0,0,0,0};
+    CANON_TOOL_TABLE t = {-1,{{0,0,0},0,0,0,0,0,0},0,0,0,0};
     if(interp_error) return t;
     PyObject *result =
         callmethod(callback, "get_tool", "i", pocket);
@@ -561,41 +556,26 @@ static void user_defined_function(int num, double arg1, double arg2) {
     Py_XDECREF(result);
 }
 
-void SET_FEED_REFERENCE(CANON_FEED_REFERENCE ref) {}
+void SET_FEED_REFERENCE(int ref) {}
 int GET_EXTERNAL_QUEUE_EMPTY() { return true; }
-CANON_DIRECTION GET_EXTERNAL_SPINDLE(int) { return CANON_STOPPED; }
+CANON_DIRECTION GET_EXTERNAL_SPINDLE() { return 0; }
 int GET_EXTERNAL_TOOL_SLOT() { return 0; }
 int GET_EXTERNAL_SELECTED_TOOL_SLOT() { return 0; }
 double GET_EXTERNAL_FEED_RATE() { return 1; }
 double GET_EXTERNAL_TRAVERSE_RATE() { return 0; }
 int GET_EXTERNAL_FLOOD() { return 0; }
 int GET_EXTERNAL_MIST() { return 0; }
-CANON_PLANE GET_EXTERNAL_PLANE() { return CANON_PLANE_XY; }
-double GET_EXTERNAL_SPEED(int spindle) { return 0; }
+CANON_PLANE GET_EXTERNAL_PLANE() { return 1; }
+double GET_EXTERNAL_SPEED() { return 0; }
 int GET_EXTERNAL_POCKETS_MAX() { return CANON_POCKETS_MAX; }
 void DISABLE_ADAPTIVE_FEED() {} 
 void ENABLE_ADAPTIVE_FEED() {} 
 
 int GET_EXTERNAL_FEED_OVERRIDE_ENABLE() {return 1;}
-int GET_EXTERNAL_SPINDLE_OVERRIDE_ENABLE(int spindle) {return 1;}
+int GET_EXTERNAL_SPINDLE_OVERRIDE_ENABLE() {return 1;}
 int GET_EXTERNAL_ADAPTIVE_FEED_ENABLE() {return 0;}
 int GET_EXTERNAL_FEED_HOLD_ENABLE() {return 1;}
 
-int GET_EXTERNAL_OFFSET_APPLIED() {return 0;}
-EmcPose GET_EXTERNAL_OFFSETS() {
-    EmcPose e;
-    e.tran.x = 0;
-    e.tran.y = 0;
-    e.tran.z = 0;
-    e.a      = 0;
-    e.b      = 0;
-    e.c      = 0;
-    e.u      = 0;
-    e.v      = 0;
-    e.w      = 0;
-    return e;
-};
-
 int GET_EXTERNAL_AXIS_MASK() {
     if(interp_error) return 7;
     PyObject *result =
@@ -705,20 +685,11 @@ void SET_NAIVECAM_TOLERANCE(double tolerance) { }
 static PyObject *parse_file(PyObject *self, PyObject *args) {
     char *f;
     char *unitcode=0, *initcode=0, *interpname=0;
-    PyObject *initcodes=0;
     int error_line_offset = 0;
     struct timeval t0, t1;
     int wait = 1;
-
-    if(!PyArg_ParseTuple(args, "sOO!|s:new-parse",
-            &f, &callback, &PyList_Type, &initcodes, &interpname))
-    {
-        initcodes = nullptr;
-        PyErr_Clear();
-        if(!PyArg_ParseTuple(args, "sO|sss:parse",
-                &f, &callback, &unitcode, &initcode, &interpname))
-            return NULL;
-    }
+    if(!PyArg_ParseTuple(args, "sO|sss", &f, &callback, &unitcode, &initcode, &interpname))
+        return NULL;
 
     if(pinterp) {
         delete pinterp;
@@ -741,37 +712,25 @@ static PyObject *parse_file(PyObject *self, PyObject *args) {
     _pos_x = _pos_y = _pos_z = _pos_a = _pos_b = _pos_c = 0;
     _pos_u = _pos_v = _pos_w = 0;
 
-    pinterp->init();
-    pinterp->open(f);
+    interp_new.init();
+    interp_new.open(f);
 
     maybe_new_line();
 
     int result = INTERP_OK;
-    if(initcodes) {
-        for(int i=0; i<PyList_Size(initcodes) && RESULT_OK; i++)
-        {
-            PyObject *item = PyList_GetItem(initcodes, i);
-            if(!item) return NULL;
-            char *code = PyString_AsString(item);
-            if(!code) return NULL;
-            result = pinterp->read(code);
-            if(!RESULT_OK) goto out_error;
-            result = pinterp->execute();
-        }
-    }
-    if(unitcode && RESULT_OK) {
-        result = pinterp->read(unitcode);
+    if(unitcode) {
+        result = interp_new.read(unitcode);
         if(!RESULT_OK) goto out_error;
-        result = pinterp->execute();
+        result = interp_new.execute();
     }
     if(initcode && RESULT_OK) {
-        result = pinterp->read(initcode);
+        result = interp_new.read(initcode);
         if(!RESULT_OK) goto out_error;
-        result = pinterp->execute();
+        result = interp_new.execute();
     }
     while(!interp_error && RESULT_OK) {
         error_line_offset = 1;
-        result = pinterp->read();
+        result = interp_new.read();
         gettimeofday(&t1, NULL);
         if(t1.tv_sec > t0.tv_sec + wait) {
             if(check_abort()) return NULL;
@@ -779,7 +738,7 @@ static PyObject *parse_file(PyObject *self, PyObject *args) {
         }
         if(!RESULT_OK) break;
         error_line_offset = 0;
-        result = pinterp->execute();
+        result = interp_new.execute();
     }
 out_error:
     if(pinterp)
@@ -810,8 +769,8 @@ static int maxerror = -1;
 static char savedError[LINELEN+1];
 static PyObject *rs274_strerror(PyObject *s, PyObject *o) {
     int err;
-    if(!PyArg_ParseTuple(o, "i", &err)) return nullptr;
-    pinterp->error_text(err, savedError, LINELEN);
+    if(!PyArg_ParseTuple(o, "i", &err)) return NULL;
+    interp_new.error_text(err, savedError, LINELEN);
     return PyString_FromString(savedError);
 }
 
@@ -1056,4 +1015,5 @@ initgcode(void) {
     PyObject_SetAttrString(m, "MIN_ERROR",
             PyInt_FromLong(INTERP_MIN_ERROR));
 }
+
 // vim:ts=8:sts=4:sw=4:et:
