@@ -65,14 +65,7 @@ suppression can produce more concise output. Future versions might
 include an option for suppressing superfluous commands.
 
 ****************************************************************************/
-#define BOOST_PYTHON_MAX_ARITY 4
-#include "python_plugin.hh"
-#include <boost/python/dict.hpp>
-#include <boost/python/extract.hpp>
-#include <boost/python/import.hpp>
-#include <boost/python/list.hpp>
-#include <boost/python/scope.hpp>
-#include <boost/python/tuple.hpp>
+#include <boost/python.hpp>
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -88,7 +81,6 @@ include an option for suppressing superfluous commands.
 #include <libintl.h>
 #include <set>
 #include <stdexcept>
-#include <new>
 
 #include "rtapi.h"
 #include "inifile.hh"		// INIFILE
@@ -100,13 +92,6 @@ include an option for suppressing superfluous commands.
 
 #include "units.h"
 
-#include <unordered_set>
-
-#include <interp_parameter_def.hh>
-using namespace interp_param_global;
-
-namespace bp = boost::python;
-
 extern char * _rs274ngc_errors[];
 
 const char *Interp::interp_status(int status) {
@@ -126,49 +111,46 @@ static char savedError[LINELEN+1];
 
 Interp::Interp()
     : log_file(stderr),
-    _setup{}
+      _setup(setup_struct())
 {
     _setup.init_once = 1;  
-  init_named_parameters();  // need this before Python init.
+    init_named_parameters();  // need this before Python init.
  
-  if (!PythonPlugin::instantiate(builtin_modules)) {  // factory
-    Error("Interp ctor: cant instantiate Python plugin");
-    return;
-  }
+    if (!PythonPlugin::instantiate(builtin_modules)) {  // factory
+	Error("Interp ctor: cant instantiate Python plugin");
+	return;
+    }
 
-// KLUDGE just to get unit tests to stop complaining about python modules we won't use anyway
-#ifndef UNIT_TEST
-  try {
-    // this import will register the C++->Python converter for Interp
-    bp::object interp_module = bp::import("interpreter");
+    try {
+	// this import will register the C++->Python converter for Interp
+	bp::object interp_module = bp::import("interpreter");
 	
-    // use a boost::cref to avoid per-call instantiation of the
-    // Interp Python wrapper (used for the 'self' parameter in handlers)
-    // since interp.init() may be called repeatedly this would create a new
-    // wrapper instance on every init(), abandoning the old one and all user attributes
-    // tacked onto it, so make sure this is done exactly once
-    _setup.pythis = new boost::python::object(boost::cref(*this));
+	// use a boost::cref to avoid per-call instantiation of the
+	// Interp Python wrapper (used for the 'self' parameter in handlers)
+	// since interp.init() may be called repeatedly this would create a new
+	// wrapper instance on every init(), abandoning the old one and all user attributes
+	// tacked onto it, so make sure this is done exactly once
+	_setup.pythis = boost::python::object(boost::cref(*this));
 	
-    // alias to 'interpreter.this' for the sake of ';py, .... ' comments
-    // besides 'this', eventually use proper instance names to handle
+	// alias to 'interpreter.this' for the sake of ';py, .... ' comments
+	// besides 'this', eventually use proper instance names to handle
 	// several instances 
-    bp::scope(interp_module).attr("this") =  *_setup.pythis;
+	bp::scope(interp_module).attr("this") =  _setup.pythis;
 
-    // make "this" visible without importing interpreter explicitly
-    bp::object retval;
-    python_plugin->run_string("from interpreter import this", retval, false);
-  }
-  catch (bp::error_already_set) {
-    std::string exception_msg;
-    if (PyErr_Occurred()) {
-      exception_msg = handle_pyerror();
-    } else
-      exception_msg = "unknown exception";
-    bp::handle_exception();
-    PyErr_Clear();
-    Error("PYTHON: exception during 'this' export:\n%s\n",exception_msg.c_str());
-  }
-#endif
+	// make "this" visible without importing interpreter explicitly
+	bp::object retval;
+	python_plugin->run_string("from interpreter import this", retval, false);
+    }
+    catch (bp::error_already_set) {
+	std::string exception_msg;
+	if (PyErr_Occurred()) {
+	    exception_msg = handle_pyerror();
+	} else
+	    exception_msg = "unknown exception";
+	bp::handle_exception();
+	PyErr_Clear();
+	Error("PYTHON: exception during 'this' export:\n%s\n",exception_msg.c_str());
+    }
 }
 
 InterpBase *makeInterp()
@@ -177,10 +159,11 @@ InterpBase *makeInterp()
 }
 
 Interp::~Interp() {
+
     if(log_file) {
         if(log_file != stderr)
             fclose(log_file);
-        log_file = nullptr;
+	log_file = 0;
     }
 }
 
@@ -463,6 +446,9 @@ int Interp::_execute(const char *command)
 		      (_setup.mdi_interrupt)) { 
 
 		      status = convert_control_functions(eblock, &_setup);
+		      // a prolog might yield INTERP_EXECUTE_FINISH too
+		      if (status == INTERP_EXECUTE_FINISH) 
+			  _setup.mdi_interrupt = true;
 		      CHP(status);
 		      if (_setup.mdi_interrupt) {
 			  _setup.mdi_interrupt = false;
@@ -665,15 +651,7 @@ int Interp::find_remappings(block_pointer block, setup_pointer settings)
 	    block->remappings.insert(STEP_PREPARE);
     }
     // User defined M-Codes in group 5
-    if (IS_USER_MCODE(block,settings,5) &&
-	!(((block->m_modes[5] == 62) && remap_in_progress("M62")) ||
-	  ((block->m_modes[5] == 63) && remap_in_progress("M63")) ||
-	  ((block->m_modes[5] == 64) && remap_in_progress("M64")) ||
-	  ((block->m_modes[5] == 65) && remap_in_progress("M65")) ||
-	  ((block->m_modes[5] == 66) && remap_in_progress("M66")) ||
-	  ((block->m_modes[5] == 67) && remap_in_progress("M67")) ||
-	  ((block->m_modes[5] == 68) && remap_in_progress("M68"))))
-	// non-recursive behavior
+    if (IS_USER_MCODE(block,settings,5))
 	block->remappings.insert(STEP_M_5);
 
     // User defined M-Codes in group 6 (including M6, M61)
@@ -776,7 +754,7 @@ int Interp::exit()
       bp::object retval, tupleargs, kwargs;
       bp::list plist;
 
-      plist.append(*_setup.pythis); // self
+      plist.append(_setup.pythis); // self
       tupleargs = bp::tuple(plist);
       kwargs = bp::dict();
 
@@ -841,14 +819,13 @@ int Interp::init()
   _setup.b_axis_wrapped = 0;
   _setup.c_axis_wrapped = 0;
   _setup.random_toolchanger = 0;
-  _setup.a_indexer_jnum = -1; // -1 means not used
-  _setup.b_indexer_jnum = -1; // -1 means not used
-  _setup.c_indexer_jnum = -1; // -1 means not used
+  _setup.a_indexer = 0;
+  _setup.b_indexer = 0;
+  _setup.c_indexer = 0;
   _setup.return_value = 0;
   _setup.value_returned = 0;
   _setup.remap_level = 0; // remapped blocks stack index
   _setup.call_state = CS_NORMAL;
-  _setup.num_spindles = 1;
 
   // default arc radius tolerances
   // we'll try to override these from the ini file below
@@ -867,22 +844,15 @@ int Interp::init()
           inifile.Find(&_setup.tool_change_at_g30, "TOOL_CHANGE_AT_G30", "EMCIO");
           inifile.Find(&_setup.tool_change_quill_up, "TOOL_CHANGE_QUILL_UP", "EMCIO");
           inifile.Find(&_setup.tool_change_with_spindle_on, "TOOL_CHANGE_WITH_SPINDLE_ON", "EMCIO");
-          inifile.Find(&_setup.a_axis_wrapped, "WRAPPED_ROTARY", "AXIS_A");
-          inifile.Find(&_setup.b_axis_wrapped, "WRAPPED_ROTARY", "AXIS_B");
-          inifile.Find(&_setup.c_axis_wrapped, "WRAPPED_ROTARY", "AXIS_C");
+          inifile.Find(&_setup.a_axis_wrapped, "WRAPPED_ROTARY", "AXIS_3");
+          inifile.Find(&_setup.b_axis_wrapped, "WRAPPED_ROTARY", "AXIS_4");
+          inifile.Find(&_setup.c_axis_wrapped, "WRAPPED_ROTARY", "AXIS_5");
           inifile.Find(&_setup.random_toolchanger, "RANDOM_TOOLCHANGER", "EMCIO");
           inifile.Find(&_setup.feature_set, "FEATURES", "RS274NGC");
-          inifile.Find(&_setup.num_spindles, "SPINDLES", "TRAJ");
 
-          if (NULL != (inistring =inifile.Find("LOCKING_INDEXER_JOINT", "AXIS_A"))) {
-              _setup.a_indexer_jnum = atol(inistring);
-          }
-          if (NULL != (inistring =inifile.Find("LOCKING_INDEXER_JOINT", "AXIS_B"))) {
-              _setup.b_indexer_jnum = atol(inistring);
-          }
-          if (NULL != (inistring =inifile.Find("LOCKING_INDEXER_JOINT", "AXIS_C"))) {
-              _setup.c_indexer_jnum = atol(inistring);
-          }
+          inifile.Find(&_setup.a_indexer, "LOCKING_INDEXER", "AXIS_3");
+          inifile.Find(&_setup.b_indexer, "LOCKING_INDEXER", "AXIS_4");
+          inifile.Find(&_setup.c_indexer, "LOCKING_INDEXER", "AXIS_5");
           inifile.Find(&_setup.orient_offset, "ORIENT_OFFSET", "RS274NGC");
 
           inifile.Find(&_setup.debugmask, "DEBUG", "EMC");
@@ -1036,18 +1006,6 @@ int Interp::init()
               Error("invalid [RS274NGC]CENTER_ARC_RADIUS_TOLERANCE_MM in ini file\n");
           }
 
-	  // ini file g52/g92 offset persistence default setting
-	  inifile.Find(&_setup.disable_g92_persistence,
-		       "DISABLE_G92_PERSISTENCE",
-		       "RS274NGC");
-
-	  // ini file m98/m99 subprogram default setting
-	  inifile.Find(&_setup.disable_fanuc_style_sub,
-		       "DISABLE_FANUC_STYLE_SUB",
-		       "RS274NGC");
-	  logDebug("init:  DISABLE_FANUC_STYLE_SUB = %d",
-		   _setup.disable_fanuc_style_sub);
-
           // close it
           inifile.Close();
       }
@@ -1088,15 +1046,6 @@ int Interp::init()
                  _setup.v_origin_offset ,
                  _setup.w_origin_offset);
 
-  // Restore G92 offset if DISABLE_G92_PERSISTENCE not set in .ini file.
-  // This can't be done with the static _required_parameters[], where
-  // the .vars file contents would reflect that setting, so instead
-  // edit the restored parameters here.
-  if (_setup.disable_g92_persistence)
-      // Persistence disabled:  clear g92 parameters
-      for (k = 5210; k < 5220; k++)
-	  pars[k] = 0;
-
   if (pars[5210]) {
       _setup.axis_offset_x = USER_TO_PROGRAM_LEN(pars[5211]);
       _setup.axis_offset_y = USER_TO_PROGRAM_LEN(pars[5212]);
@@ -1179,7 +1128,7 @@ int Interp::init()
   _setup.sequence_number = 0;   /*DOES THIS NEED TO BE AT TOP? */
 //_setup.speed set in Interp::synch
   _setup.speed_feed_mode = CANON_INDEPENDENT;
-// setup.spindle_mode  set in interp_synch;
+  _setup.spindle_mode = CONSTANT_RPM;
 //_setup.speed_override set in Interp::synch
 //_setup.spindle_turning set in Interp::synch
 //_setup.stack does not need initialization
@@ -1259,7 +1208,7 @@ int Interp::init()
 	  bp::object retval, tupleargs, kwargs;
 	  bp::list plist;
 
-	  plist.append(*_setup.pythis); // self
+	  plist.append(_setup.pythis); // self
 	  tupleargs = bp::tuple(plist);
 	  kwargs = bp::dict();
 
@@ -1274,12 +1223,6 @@ int Interp::init()
   return INTERP_OK;
 }
 
-void Interp::set_loop_on_main_m99(bool state) {
-    // Enable/disable M99 main program endless looping
-    _setup.loop_on_main_m99 = state;
-}
-
-
 /***********************************************************************/
 
 /*! Interp::load_tool_table
@@ -1394,7 +1337,7 @@ int Interp::open(const char *filename) //!< string: the name of the input NC-pro
          NULL), NCE_FILE_ENDED_WITH_NO_PERCENT_SIGN);
     length = strlen(line);
     if (length == (LINELEN - 1)) {   // line is too long. need to finish reading the line to recover
-      for (; fgetc(_setup.file_pointer) != '\n' && !feof(_setup.file_pointer););
+      for (; fgetc(_setup.file_pointer) != '\n';);      // could look for EOF
       ERS(NCE_COMMAND_TOO_LONG);
     }
     for (index = (length - 1);  // index set on last char
@@ -1568,14 +1511,10 @@ int Interp::_read(const char *command)  //!< may be NULL or a string to read
   block_pointer eblock = &EXECUTING_BLOCK(_setup);
 
   if ((_setup.call_state > CS_NORMAL) && 
-      (eblock->call_type != CT_NGC_OWORD_SUB)  &&
-      (eblock->call_type != CT_NGC_M98_SUB)  &&
-      (eblock->call_type != CT_NONE)  &&
+      (eblock->call_type > CT_NGC_OWORD_SUB)  && 
       ((eblock->o_type == O_call) ||
-       (eblock->o_type == M_98) ||
        (eblock->o_type == O_return) ||
-       (eblock->o_type == O_endsub) ||
-       (eblock->o_type == M_99))) {
+       (eblock->o_type == O_endsub))) {
 
       logDebug("read(): skipping read");
       _setup.line_length = 0;
@@ -1637,12 +1576,8 @@ int Interp::_read(const char *command)  //!< may be NULL or a string to read
             EXECUTING_BLOCK(_setup).o_type = 0;
 	}
     }
-  } else if (read_status == INTERP_ENDFILE) {
-      // If skipping but not defining the main program, we hit EOF
-      // before finding the sub we're looking for; error out
-      CHKS((_setup.skipping_o != NULL),
-	   "Failed to find sub 'O%s' before EOF", _setup.skipping_o);
-  } else
+  } else if (read_status == INTERP_ENDFILE);
+  else
     ERP(read_status);
   return read_status;
 }
@@ -1672,11 +1607,10 @@ int Interp::unwind_call(int status, const char *file, int line, const char *func
 	    sub->subName = 0;
 	}
 
-	if (sub->call_type != CT_NGC_M98_SUB) // M98:  pass #1..#30 from parent
-	    for(i=0; i<INTERP_SUB_PARAMS; i++) {
-		_setup.parameters[i+INTERP_FIRST_SUBROUTINE_PARAM] =
-		    sub->saved_params[i];
-	    }
+	for(i=0; i<INTERP_SUB_PARAMS; i++) {
+	    _setup.parameters[i+INTERP_FIRST_SUBROUTINE_PARAM] =
+		sub->saved_params[i];
+	}
 
 	// When called from Interp::close via Interp::reset, this one is NULL
 	if (!_setup.file_pointer) continue;
@@ -1697,6 +1631,7 @@ int Interp::unwind_call(int status, const char *file, int line, const char *func
 	_setup.sequence_number = sub->sequence_number;
 	logDebug("unwind_call: setting sequence number=%d from frame %d",
 		_setup.sequence_number,_setup.call_level);
+
     }
     // call_level == 0 here.
  
@@ -1910,19 +1845,31 @@ int Interp::save_parameters(const char *filename,      //!< name of file to writ
   int index;                    // index into _required_parameters
   int k;
 
-  std::string tempfile = std::string(filename) + ".new";
-  outfile = fopen(tempfile.c_str(), "w");
-  CHKS((outfile == NULL), NCE_CANNOT_OPEN_VARIABLE_FILE);
+  if(access(filename, F_OK)==0) 
+  {
+    // rename as .bak
+    int r;
+    r = snprintf(line, sizeof(line), "%s%s", filename, RS274NGC_PARAMETER_FILE_BACKUP_SUFFIX);
+    CHKS((r >= (int)sizeof(line)), NCE_CANNOT_CREATE_BACKUP_FILE);
+    CHKS((rename(filename, line) != 0), NCE_CANNOT_CREATE_BACKUP_FILE);
 
-  infile = fopen(filename, "r");
-  if(!infile)
+    // open backup for reading
+    infile = fopen(line, "r");
+    CHKS((infile == NULL), NCE_CANNOT_OPEN_BACKUP_FILE);
+  } else {
+    // it's OK if the parameter file doesn't exist yet
+    // it will now be created with a default list of parameters
     infile = fopen("/dev/null", "r");
+  }
+  // open original for writing
+  outfile = fopen(filename, "w");
+  CHKS((outfile == NULL), NCE_CANNOT_OPEN_VARIABLE_FILE);
 
   k = 0;
   index = 0;
   required = _required_parameters[index++];
   while (feof(infile) == 0) {
-    if (fgets(line, sizeof(line), infile) == NULL) {
+    if (fgets(line, 256, infile) == NULL) {
       break;
     }
     // try for a variable-value match
@@ -1959,17 +1906,7 @@ int Interp::save_parameters(const char *filename,      //!< name of file to writ
       required = _required_parameters[index++];
     }
   }
-
-  fflush(outfile);
-  fdatasync(fileno(outfile));
   fclose(outfile);
-  std::string bakfile = std::string(filename)
-                            + RS274NGC_PARAMETER_FILE_BACKUP_SUFFIX;
-  unlink(bakfile.c_str());
-  if(link(filename, bakfile.c_str()) < 0)
-    perror("link (updating variable file)");
-  if(rename(tempfile.c_str(), filename) < 0)
-    perror("rename (updating variable file)");
   return INTERP_OK;
 }
 
@@ -1996,35 +1933,33 @@ int Interp::synch()
 {
 
   char file_name[LINELEN];
-  _setup.current_x  = GET_EXTERNAL_POSITION_X();
-  _setup.current_y  = GET_EXTERNAL_POSITION_Y();
-  _setup.current_z  = GET_EXTERNAL_POSITION_Z();
+
+  _setup.control_mode = GET_EXTERNAL_MOTION_CONTROL_MODE();
   _setup.AA_current = GET_EXTERNAL_POSITION_A();
   _setup.BB_current = GET_EXTERNAL_POSITION_B();
   _setup.CC_current = GET_EXTERNAL_POSITION_C();
-  _setup.u_current  = GET_EXTERNAL_POSITION_U();
-  _setup.v_current  = GET_EXTERNAL_POSITION_V();
-  _setup.w_current  = GET_EXTERNAL_POSITION_W();
-
-  _setup.control_mode = GET_EXTERNAL_MOTION_CONTROL_MODE();
   _setup.current_pocket = GET_EXTERNAL_TOOL_SLOT();
+  _setup.current_x = GET_EXTERNAL_POSITION_X();
+  _setup.current_y = GET_EXTERNAL_POSITION_Y();
+  _setup.current_z = GET_EXTERNAL_POSITION_Z();
+  _setup.u_current = GET_EXTERNAL_POSITION_U();
+  _setup.v_current = GET_EXTERNAL_POSITION_V();
+  _setup.w_current = GET_EXTERNAL_POSITION_W();
   _setup.feed_rate = GET_EXTERNAL_FEED_RATE();
   _setup.flood = GET_EXTERNAL_FLOOD();
   _setup.length_units = GET_EXTERNAL_LENGTH_UNIT_TYPE();
   _setup.mist = GET_EXTERNAL_MIST();
   _setup.plane = GET_EXTERNAL_PLANE();
   _setup.selected_pocket = GET_EXTERNAL_SELECTED_TOOL_SLOT();
+  _setup.speed = GET_EXTERNAL_SPEED();
+  _setup.spindle_turning = GET_EXTERNAL_SPINDLE();
   _setup.pockets_max = GET_EXTERNAL_POCKETS_MAX();
   _setup.traverse_rate = GET_EXTERNAL_TRAVERSE_RATE();
   _setup.feed_override = GET_EXTERNAL_FEED_OVERRIDE_ENABLE();
+  _setup.speed_override = GET_EXTERNAL_SPINDLE_OVERRIDE_ENABLE();
   _setup.adaptive_feed = GET_EXTERNAL_ADAPTIVE_FEED_ENABLE();
   _setup.feed_hold = GET_EXTERNAL_FEED_HOLD_ENABLE();
-  for (int s = 0; s < EMCMOT_MAX_SPINDLES; s++){
-	  _setup.speed[s] = GET_EXTERNAL_SPEED(s);
-	  _setup.spindle_turning[s] = GET_EXTERNAL_SPINDLE(s);
-	  _setup.speed_override[s] = GET_EXTERNAL_SPINDLE_OVERRIDE_ENABLE(s);
-	  _setup.spindle_mode[s] = CONSTANT_RPM;
-  }
+
   GET_EXTERNAL_PARAMETER_FILE_NAME(file_name, (LINELEN - 1));
   save_parameters(((file_name[0] ==
                              0) ?
@@ -2033,7 +1968,7 @@ int Interp::synch()
 
   load_tool_table();   /*  must set  _setup.tool_max first */
 
-  // read_inputs(&_setup); // input/probe/toolchange
+  // read_inputs(&_setup); // input/probe/toolchange 
 
   write_settings(&_setup);
 
@@ -2361,21 +2296,20 @@ int Interp::ini_load(const char *filename)
     logDebug("Opened inifile:%s:", filename);
 
 
-    char parameter_file_name[LINELEN]={};
     if (NULL != (inistring = inifile.Find("PARAMETER_FILE", "RS274NGC"))) {
-        strncpy(parameter_file_name, inistring, LINELEN);
-
-        if (parameter_file_name[LINELEN-1] != '\0') {
+	// found it
+	strncpy(_parameter_file_name, inistring, LINELEN);
+        if (_parameter_file_name[LINELEN-1] != '\0') {
             logDebug("%s:[RS274NGC]PARAMETER_FILE is too long (max len %d)", filename, LINELEN-1);
-        } else {
-          logDebug("found PARAMETER_FILE:%s:", parameter_file_name);
+            inifile.Close();
+            _parameter_file_name[0] = '\0';
+            return -1;
         }
+        logDebug("found PARAMETER_FILE:%s:", _parameter_file_name);
     } else {
-      // not found, leave RS274NGC_PARAMETER_FILE alone
+	// not found, leave RS274NGC_PARAMETER_FILE alone
         logDebug("did not find PARAMETER_FILE");
     }
-    SET_PARAMETER_FILE_NAME(parameter_file_name);
-    CHKS(strlen(parameter_file_name) > 0, _("Parameter file name is missing"));
 
     // close it
     inifile.Close();
@@ -2569,29 +2503,25 @@ FILE *Interp::find_ngc_file(setup_pointer settings,const char *basename, char *f
     return newFP;
 }
 
+static std::set<std::string> stringtable;
+
 const char *strstore(const char *s)
 {
-    static std::unordered_set<std::string> stringtable;
     using namespace std;
 
-    if (s == nullptr) {
+    if (s == NULL)
         throw invalid_argument("strstore(): NULL argument");
-    }
-    auto pair = stringtable.insert(s);
+    pair< set<string>::iterator, bool > pair = stringtable.insert(s);
     return pair.first->c_str();
 }
 
 context_struct::context_struct()
 : position(0), sequence_number(0), filename(""), subName(""),
-  m98_loop_counter(-1), context_status(0), call_type(0)
+context_status(0), call_type(0), py_return_type(0), py_returned_double(0),
+py_returned_int(0)
 {
     memset(saved_params, 0, sizeof(saved_params));
     memset(saved_g_codes, 0, sizeof(saved_g_codes));
     memset(saved_m_codes, 0, sizeof(saved_m_codes));
     memset(saved_settings, 0, sizeof(saved_settings));
 }
-
-void context_struct::clear()
-{
-    new (this) context_struct();
-}
