@@ -37,8 +37,6 @@
 #include <glob.h>
 #include <wordexp.h>
 
-#include <saicanon.hh>
-
 InterpBase *pinterp;
 #define interp_new (*pinterp)
 const char *prompt = "READ => ";
@@ -336,7 +334,7 @@ int read_tool_file(  /* ARGUMENTS         */
       tool_file_name = buffer;
     }
 
-  return loadToolTable(tool_file_name, _sai._tools, 0, 0);
+  return loadToolTable(tool_file_name, _tools, 0, 0, 0);
 }
 
 /************************************************************************/
@@ -554,7 +552,7 @@ int main (int argc, char ** argv)
   block_delete = OFF;
   print_stack = OFF;
   tool_flag = 0;
-  SET_PARAMETER_FILE_NAME(default_name);
+  strcpy(_parameter_file_name, default_name);
   _outfile = stdout; /* may be reset below */
   go_flag = 0;
 
@@ -565,7 +563,7 @@ int main (int argc, char ** argv)
       switch(c) {
           case 'p': interp = optarg; break;
           case 't': read_tool_file(optarg); tool_flag=1; break;
-          case 'v': SET_PARAMETER_FILE_NAME(optarg); break;
+          case 'v': strcpy(_parameter_file_name, optarg); break;
           case 'b': block_delete = (block_delete == OFF) ? ON : OFF; break;
           case 's': print_stack = (print_stack == OFF) ? ON : OFF; break;
           case 'n': do_next = atoi(optarg); break;
