@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/python2.4
 # -*- encoding: utf-8 -*-
 #    This is pncconf, a graphical configuration editor for LinuxCNC
 #    Chris Morley copyright 2009
@@ -17,7 +17,7 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USAimport os
 import os
 import gtk
 import time
@@ -474,9 +474,9 @@ But there is not one in the machine-named folder.."""),True)
         self.encoder = self.a.encoder_sig(axis)
         #print axis," encoder--",self.encoder
         pwm_sig = self.a.pwmgen_sig(axis)
-        self.pwm = self.a.make_pinname(pwm_sig)
+        self.pwm = self.d.make_pinname(pwm_sig)
         #print axis," pwgen--",self.pwmgen
-        pump = self.a.findsignal("charge-pump")
+        pump = self.d.findsignal("charge-pump")
 
         if self.stepgen:
             state = True
@@ -620,7 +620,7 @@ But there is not one in the machine-named folder.."""),True)
         # for encoder signals
         if self.encoder: 
             #print self.encoder,"--",self.encoder[4:5],self.encoder[10:],self.encoder[6:7] 
-            self.enc_signalname = self.a.make_pinname(self.encoder)
+            self.enc_signalname = self.d.make_pinname(self.encoder)
             if w[axis+"invertmotor"].get_active():
                 self.enc_scale = get_value(w[axis + "encoderscale"]) * -1
             else:
@@ -654,7 +654,7 @@ But there is not one in the machine-named folder.."""),True)
                 for i in pwminvertlist:
                     halrun.write("setp    "+i+".invert_output true\n")
             else: # sserial PWM
-                pwm_enable = self.a.make_pinname(pwm_sig,gpionumber = False, prefixonly = True) # get prefix only
+                pwm_enable = self.d.make_pinname(pwm_sig,False,True) # get prefix only
                 halrun.write("net enable %s \n"%  (pwm_enable +"analogena"))
                 halrun.write("setp   "+self.pwm+"-minlim   %.1f\n"% pwmminlimit)
                 halrun.write("setp   "+self.pwm+"-maxlim   %.1f\n"% pwmmaxlimit)
@@ -668,19 +668,15 @@ But there is not one in the machine-named folder.."""),True)
         # for step gen components
         if self.stepgen:                        
             # check current component number to signal's component number                             
-            self.step_signalname = self.a.make_pinname(self.stepgen) 
+            self.step_signalname = self.d.make_pinname(self.stepgen) 
             #print "step_signal--",self.step_signalname   
             if w[axis+"invertmotor"].get_active():
                 self.scale = get_value(w[axis + "stepscale"]) * -1
             else:
                 self.scale = get_value(w[axis + "stepscale"]) * 1
-
-            # invert step pins if requested
             stepinvertlist = self.a.stepgen_invert_pins(step_sig)
-            for i in stepinvertlist[0]:
-                   print >>file, "setp   " + self.step_signalname + ".step.invert_output   true"
-            for i in stepinvertlist[1]:
-                   print >>file, "setp   " + self.step_signalname + ".direction.invert_output   true"
+            for i in stepinvertlist:
+                halrun.write("setp    "+i+".invert_output true\n")
             halrun.write("setp %s.step_type 0 \n"% (self.step_signalname))
             halrun.write("setp %s.control-type 1 \n"% (self.step_signalname))
             halrun.write("setp %s.position-scale %f \n"% (self.step_signalname,self.scale))
@@ -893,14 +889,14 @@ But there is not one in the machine-named folder.."""),True)
         if not self.a.check_for_rt():
             return
         # one needs real time, pwm gen and an encoder for open loop testing.
-        temp = self.a.findsignal( (axis + "-encoder-a"))
-        self.enc = self.a.make_pinname(temp)
-        temp = self.a.findsignal( (axis + "-resolver"))
-        self.res = self.a.make_pinname(temp)
-        pwm_sig = self.a.findsignal( (axis + "-pwm-pulse"))
-        self.pwm = self.a.make_pinname(pwm_sig)
-        pot_sig = self.a.findsignal(axis+"-pot-output")
-        self.pot = self.a.make_pinname(pot_sig)
+        temp = self.d.findsignal( (axis + "-encoder-a"))
+        self.enc = self.d.make_pinname(temp)
+        temp = self.d.findsignal( (axis + "-resolver"))
+        self.res = self.d.make_pinname(temp)
+        pwm_sig = self.d.findsignal( (axis + "-pwm-pulse"))
+        self.pwm = self.d.make_pinname(pwm_sig)
+        pot_sig = self.d.findsignal(axis+"-pot-output")
+        self.pot = self.d.make_pinname(pot_sig)
 
         if axis == "s":
             if (not self.pwm and not self.pot) and (not self.enc and not self.res):
@@ -936,7 +932,7 @@ But there is not one in the machine-named folder.."""),True)
             pwmmaxlimit = get_value(widgets[axis+"outputmaxlimit"])
             pwmmaxoutput = get_value(widgets[axis+"outputscale"])
         enc_scale = get_value(widgets[axis+"encoderscale"])
-        pump = self.a.findsignal("charge-pump")
+        pump = self.d.findsignal("charge-pump")
         print 'fast %d,max %d, ss max %d, dac_scale %d'%(fastdac,max_dac,pwmmaxoutput,dac_scale)
         halrun.write("loadrt threads period1=%d name1=base-thread fp1=0 period2=%d name2=servo-thread \n" % (100000, self.d.servoperiod  ))
         load,read,write = self.a.hostmot2_command_string()
@@ -993,7 +989,7 @@ But there is not one in the machine-named folder.."""),True)
                     halrun.write("setp    "+i+".invert_output true\n")
 
             else: # sserial PWM
-                pwm_enable = self.a.make_pinname(pwm_sig,False,True) # get prefix only
+                pwm_enable = self.d.make_pinname(pwm_sig,False,True) # get prefix only
                 if 'analogout5' in self.pwm:
                     enable ='spinena'
                 else:
@@ -1129,7 +1125,7 @@ But there is not one in the machine-named folder.."""),True)
         halrun = self.halrun
         def write_pins(pname,p,i,t):
             if p in signallist:
-                pinname  = self.a.make_pinname(pname)
+                pinname  = self.d.make_pinname(pname)
                 if pinname:
                     #print p, pname, i
                     if p == "estop-out": signal = p
