@@ -182,14 +182,11 @@ int hm2_absenc_setup_biss(hostmot2_t *hm2, hm2_sserial_remote_t *chan,
     chan->reg_0_addr = md->base_address 
             + (0 * md->register_stride)
             + chan->index * md->instance_stride;
-    chan->reg_1_addr = md->base_address 
+    chan->reg_cs_addr = md->base_address 
             + (1 * md->register_stride)
             + chan->index * md->instance_stride;
-    chan->reg_2_addr = md->base_address 
-            + (2 * md->register_stride)
-            + chan->index * md->instance_stride;
     hm2->absenc.biss_global_start_addr = md->base_address 
-            + (3 * md->register_stride);
+            + (2 * md->register_stride);
     chan->data_written = 0;
     
     chan->params->float_param = 500;
@@ -266,20 +263,13 @@ int hm2_absenc_parse_format(hm2_sserial_remote_t *chan,  hm2_absenc_format_t *de
                 conf->DataDir = LBP_IN;
                 conf->DataLength = q;
                 strcpy(conf->NameString, name);
-                strcpy(conf->UnitString, "none");
                 conf->RecordType = 0xA0;
                 conf->ParmAddr = 0;
-                conf->Flags = 0;
-                // Modifier flags
-                while (strchr("gGmM", *format)){
-                    if (*format=='g' || *format=='G'){
-                        conf->Flags |= 0x01;
-                        format++;
-                    }
-                    if (*format=='m' || *format=='M'){
-                        conf->Flags |= 0x02;
-                        format++;
-                    }
+                if (*format=='g' || *format=='G'){
+                    strcpy(conf->UnitString, "gray");
+                    format++;
+                } else {
+                    strcpy(conf->UnitString, "none");
                 }
                 switch(*format){
                 case 'b':
@@ -331,8 +321,8 @@ int hm2_absenc_parse_format(hm2_sserial_remote_t *chan,  hm2_absenc_format_t *de
                     conf->ParmMin = 0;
                     break;
                 default:
-                    HM2_ERR_NO_LL("The \"g\" and \"m\"format modifiers must be"
-                                  "paired with one of the other data types\n");
+                    HM2_ERR_NO_LL("The \"g\" format modifier must be paired "
+                            "with one of the other data types\n");
                     return -EINVAL;
                 }
                 
@@ -372,7 +362,7 @@ int hm2_absenc_parse_md(hostmot2_t *hm2, int md_index) {
         }
         break;
     case HM2_GTAG_BISS:
-        if ( ! hm2_md_is_consistent_or_complain(hm2, md_index, 0, 4, 4, 0x07)) {
+        if ( ! hm2_md_is_consistent_or_complain(hm2, md_index, 0, 3, 4, 0x03)) {
             HM2_ERR("inconsistent absenc Module Descriptor!\n");
             return -EINVAL;
         }
@@ -559,7 +549,7 @@ void hm2_absenc_process_tram_read(hostmot2_t *hm2, long period) {
 void hm2_absenc_write(hostmot2_t *hm2){
 
     int i;
-    rtapi_u32 buff, buff2, buff3, dds, filt;
+    rtapi_u32 buff, buff2, buff3;
     if (hm2->absenc.num_chans <= 0) return;
 
     for (i = 0; i < hm2->absenc.num_chans; i ++) {
@@ -581,37 +571,22 @@ void hm2_absenc_write(hostmot2_t *hm2){
                 chan->data_written = buff;
             }
             break;
-        
         case HM2_GTAG_BISS:
             if (chan->params->timer_num > 4) chan->params->timer_num = 4;
-            dds = ((rtapi_u32)(0x10000 * (chan->params->float_param * 1000
-            / hm2->absenc.clock_frequency)));
-            filt = 0x8000/dds;               // RX data filter set to 1/2 a clock period
-            if (filt > 63) { filt = 63; }    // bound so we dont splatter into adjacent fields
-            buff = dds << 16
-            | filt << 10				
-            | chan->num_read_bits;
+            buff = ((rtapi_u32)(0x10000 * (chan->params->float_param * 1000
+                    / hm2->absenc.clock_frequency))) << 16
+                    | chan->params->timer_num << 12
+                    | (chan->params->timer_num == 0) << 10
+                    | (chan->params->timer_num != 0) << 11
+                    | chan->num_read_bits;
             if (buff != chan->data_written){
-               HM2_PRINT("BISS DDS set to %d\n",dds);
-               HM2_PRINT("BISS Filter set to %d\n",filt);
-               hm2->llio->write(hm2->llio,
-                        chan->reg_1_addr,
+                hm2->llio->write(hm2->llio,
+                        chan->reg_cs_addr,
                         &buff,
                         sizeof(rtapi_u32));
                 chan->data_written = buff;
-             }     
-             buff2 =   chan->params->timer_num << 12
-                    | (chan->params->timer_num == 0) << 8
-                    | (chan->params->timer_num != 0) << 9;
-             if (buff2 != chan->data2_written){
-                hm2->llio->write(hm2->llio,
-                        chan->reg_2_addr,
-                        &buff2,
-                        sizeof(rtapi_u32));
-                chan->data2_written = buff2;
-              }
-        break;
-        
+            }
+            break;
         case HM2_GTAG_FABS:
             if (chan->params->timer_num > 4) chan->params->timer_num = 4;
             if (chan->params->u32_param > 15) chan->params->u32_param = 15;
@@ -670,8 +645,8 @@ void hm2_absenc_cleanup(hostmot2_t *hm2) {
 
 void hm2_absenc_print_module(hostmot2_t *hm2) {
     int i;
-    if (hm2->absenc.num_chans <= 0) return;
     HM2_PRINT("Absolute Encoder (Generic): %d\n", hm2->absenc.num_chans);
+    if (hm2->absenc.num_chans <= 0) return;
     HM2_PRINT("    clock_frequency: %d Hz (%s MHz)\n",
             hm2->absenc.clock_frequency,
             hm2_hz_to_mhz(hm2->absenc.clock_frequency));
