@@ -22,7 +22,7 @@
  *
  *  You should have received a copy of the GNU General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111 USA
  *
  *  THE AUTHORS OF THIS LIBRARY ACCEPT ABSOLUTELY NO LIABILITY FOR
  *  ANY HARM OR LOSS RESULTING FROM ITS USE.  IT IS _EXTREMELY_ UNWISE
@@ -42,7 +42,6 @@
 #include "hal.h"		/* HAL public API decls */
 #include "../hal_priv.h"	/* private HAL decls */
 #include "halcmd_commands.h"
-#include <rtapi_mutex.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -52,6 +51,7 @@
 #include <sys/wait.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <signal.h>
 #include <errno.h>
 #include <time.h>
 #include <fnmatch.h>
@@ -90,7 +90,6 @@ static void save_signals(FILE *dst, int only_unlinked);
 static void save_links(FILE *dst, int arrows);
 static void save_nets(FILE *dst, int arrows);
 static void save_params(FILE *dst);
-static void save_unconnected_input_pin_values(FILE *dst);
 static void save_threads(FILE *dst);
 static void print_help_commands(void);
 
@@ -621,8 +620,6 @@ int do_newsig_cmd(char *name, char *type)
 	retval = hal_signal_new(name, HAL_U32);
     } else if (strcasecmp(type, "s32") == 0) {
 	retval = hal_signal_new(name, HAL_S32);
-    } else if (strcasecmp(type, "port") == 0) {
-	retval = hal_signal_new(name, HAL_PORT);
     } else {
 	halcmd_error("Unknown signal type '%s'\n", type);
 	retval = -EINVAL;
@@ -639,7 +636,6 @@ static int set_common(hal_type_t type, void *d_ptr, char *value) {
     double fval;
     long lval;
     unsigned long ulval;
-    unsigned uval;
     char *cp = value;
 
     switch (type) {
@@ -684,20 +680,6 @@ static int set_common(hal_type_t type, void *d_ptr, char *value) {
 	    *((hal_u32_t *) (d_ptr)) = ulval;
 	}
 	break;
-    case HAL_PORT:
-        uval = strtoul(value, &cp, 0);
-        if ((*cp != '\0') && (!isspace(*cp))) {
-            halcmd_error("value '%s' invalid for PORT\n", value);
-            retval = -EINVAL;
-        } else {
-            if((*((hal_port_t*)d_ptr) != 0) && (hal_port_buffer_size(*((hal_port_t*)d_ptr)) > 0)) {
-                halcmd_error("port is already allocated with %u bytes.\n", hal_port_buffer_size(*((hal_port_t*)d_ptr)));
-                retval = -EINVAL;
-        } else {
-            *((hal_port_t*) (d_ptr)) = hal_port_alloc(uval);
-        }
-    }
-    break;
     default:
 	/* Shouldn't get here, but just in case... */
 	halcmd_error("bad type %d\n", type);
@@ -866,8 +848,8 @@ int do_sets_cmd(char *name, char *value)
 	halcmd_error("signal '%s' not found\n", name);
 	return -EINVAL;
     }
-    /* found it - it have a writer? if it is a port we can set its buffer size */
-    if ((sig->type != HAL_PORT) && (sig->writers > 0)) {
+    /* found it - does it have a writer? */
+    if (sig->writers > 0) {
 	rtapi_mutex_give(&(hal_data->mutex));
 	halcmd_error("signal '%s' already has writer(s)\n", name);
 	return -EINVAL;
@@ -952,7 +934,6 @@ static int get_type(char ***patterns) {
     if(strcmp(typestr, "u32") == 0) return HAL_U32;
     if(strcmp(typestr, "signed") == 0) return HAL_S32;
     if(strcmp(typestr, "unsigned") == 0) return HAL_U32;
-    if(strcmp(typestr, "port") == 0) return HAL_PORT;
     return -1;
 }
 
@@ -1403,29 +1384,6 @@ static char *guess_comp_name(char *prog_name)
     return name;
 }
 
-static void reset_getopt_state() {
-/*
-
-It turns out that it is not portable to reset the state of getopt, so that
-a different argv list can be parsed.
-
-https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=192834
-
-(though that thread ends with the bug being closed as fixed in lenny, it
-is not fixed or has regressed by debian jessie)
-*/
-
-#ifdef __GNU_LIBRARY__
-    optind = 0;
-#else
-    optind = 1;
-#endif
-
-#ifdef HAVE_OPTRESET
-    optreset = 1;
-#endif
-}
-
 int do_loadusr_cmd(char *args[])
 {
     int wait_flag, wait_comp_flag, ignore_flag;
@@ -1448,7 +1406,7 @@ int do_loadusr_cmd(char *args[])
     prog_name = NULL;
 
     /* check for options (-w, -i, and/or -r) */
-    reset_getopt_state();
+    optind = 0;
     while (1) {
 	int c = getopt(argc, args, "+wWin:");
 	if(c == -1) break;
@@ -2197,9 +2155,6 @@ static const char *data_type(int type)
     case HAL_U32:
 	type_str = "u32  ";
 	break;
-    case HAL_PORT:
-	type_str = "port ";
-	break;
     default:
 	/* Shouldn't get here, but just in case... */
 	type_str = "undef";
@@ -2224,9 +2179,6 @@ static const char *data_type2(int type)
     case HAL_U32:
 	type_str = "u32";
 	break;
-    case HAL_PORT:
-	type_str = "port";
-	break;
     default:
 	/* Shouldn't get here, but just in case... */
 	type_str = "undef";
@@ -2345,10 +2297,6 @@ static char *data_value(int type, void *valptr)
 	snprintf(buf, 14, "  0x%08lX", (unsigned long)*((hal_u32_t *) valptr));
 	value_str = buf;
 	break;
-    case HAL_PORT:
-	snprintf(buf, 14, "  %10u", hal_port_buffer_size(*((hal_port_t*) valptr)));
-	value_str = buf;
-	break;
     default:
 	/* Shouldn't get here, but just in case... */
 	value_str = "   undef    ";
@@ -2382,11 +2330,6 @@ static char *data_value2(int type, void *valptr)
 	snprintf(buf, 14, "%ld", (unsigned long)*((hal_u32_t *) valptr));
 	value_str = buf;
 	break;
-    case HAL_PORT:
-	snprintf(buf, 14, "%u", hal_port_buffer_size(*((hal_port_t*) valptr)));
-	value_str = buf;
-	break;
-
     default:
 	/* Shouldn't get here, but just in case... */
 	value_str = "unknown_type";
@@ -2414,17 +2357,13 @@ int do_save_cmd(char *type, char *filename)
     if (type == 0 || *type == '\0') {
 	type = "all";
     }
-    if (   (strcmp(type, "all")  == 0)
-	|| (strcmp(type, "allu") == 0) ) {
+    if (strcmp(type, "all" ) == 0) {
 	/* save everything */
 	save_comps(dst);
 	save_aliases(dst);
-	save_signals(dst, 1);
-	save_nets(dst, 3);
+        save_signals(dst, 1);
+        save_nets(dst, 3);
 	save_params(dst);
-	if (strcmp(type,"allu") == 0) {
-	    save_unconnected_input_pin_values(dst);
-	}
 	save_threads(dst);
     } else if (strcmp(type, "comp") == 0) {
 	save_comps(dst);
@@ -2454,8 +2393,6 @@ int do_save_cmd(char *type, char *filename)
 	save_params(dst);
     } else if (strcmp(type, "thread") == 0) {
 	save_threads(dst);
-    } else if (strcmp(type, "unconnectedinpins") == 0) {
-	save_unconnected_input_pin_values(dst);
     } else {
 	halcmd_error("Unknown 'save' type '%s'\n", type);
         if (dst != stdout) fclose(dst);
@@ -2726,25 +2663,6 @@ static void save_threads(FILE *dst)
     rtapi_mutex_give(&(hal_data->mutex));
 }
 
-static void save_unconnected_input_pin_values(FILE *dst)
-{
-    hal_pin_t *pin;
-    void *dptr;
-    int next;
-    fprintf(dst, "# unconnected pin values\n");
-    for(next = hal_data->pin_list_ptr; next; next=pin->next_ptr)
-    {
-        pin = SHMPTR(next);
-        if (   (pin->signal == 0)
-            && ( (pin->dir == HAL_IN) || (pin->dir == HAL_IO) )
-           ) {
-            dptr = &(pin->dummysig);
-            fprintf(dst, "setp %s %s\n",
-                   pin->name, data_value((int) pin->type, dptr));
-        }
-    }
-}
-
 int do_setexact_cmd() {
     int retval = 0;
     rtapi_mutex_get(&(hal_data->mutex));
@@ -2800,7 +2718,7 @@ int do_help_cmd(char *command)
 	printf("  Starts user space program 'progname', passing\n");
 	printf("  'progargs' to it.  Options are:\n");
 	printf("  -W  wait for HAL component to become ready\n");
-	printf("  -Wn NAME  wait for component named NAME to become ready\n");
+	printf("  -Wn name to wait for the component, which will have the given name.\n");
 	printf("  -w  wait for program to finish\n");
 	printf("  -i  ignore program return value (use with -w)\n");
     } else if ((strcmp(command, "linksp") == 0) || (strcmp(command,"linkps") == 0)) {
@@ -2835,7 +2753,7 @@ int do_help_cmd(char *command)
     } else if (strcmp(command, "newsig") == 0) {
 	printf("newsig signame type\n");
 	printf("  Creates a new signal called 'signame'.  Type\n");
-	printf("  is 'bit', 'float', 'port', 'u32', or 's32'.\n");
+	printf("  is 'bit', 'float', 'u32', or 's32'.\n");
     } else if (strcmp(command, "delsig") == 0) {
 	printf("delsig signame\n");
 	printf("  Deletes signal 'signame'.  If 'signame is 'all',\n");
@@ -2858,9 +2776,7 @@ int do_help_cmd(char *command)
 #endif
     } else if (strcmp(command, "sets") == 0) {
 	printf("sets signame value\n");
-	printf("  Sets a non-port signal 'signame' to 'value' (if signal has no writers).\n");
-    printf("  If 'signame' is a port signal (that has not previously been allocated),\n");
-    printf("  then 'value' is the new maximum size in bytes of that port.\n");
+	printf("  Sets signal 'signame' to 'value' (if signal has no writers).\n");
     } else if (strcmp(command, "getp") == 0) {
 	printf("getp paramname\n");
 	printf("getp pinname\n");
@@ -2872,7 +2788,6 @@ int do_help_cmd(char *command)
     } else if (strcmp(command, "gets") == 0) {
 	printf("gets signame\n");
 	printf("  Gets the value of signal 'signame'.\n");
-    printf("  If signal 'signame' is a port, returns the buffer size of that port.\n");
     } else if (strcmp(command, "stype") == 0) {
 	printf("stype signame\n");
 	printf("  Gets the type of signal 'signame'\n");
@@ -2920,10 +2835,8 @@ int do_help_cmd(char *command)
 	printf("  \"halcmd -f filename\".\n");
 	printf("  Type can be 'comp', 'alias', 'sig[u]', 'signal', 'link[a]'\n");
         printf("  'net[a]', 'netl', 'netla', netal', 'param', 'parameter,\n");
-	printf("  'unconnectedinpins', 'all, 'allu', or 'thread'.\n");
+	printf("  or 'thread'.\n");
         printf("  (A final 'a' character (like 'neta' means show arrows for pin direction.)\n");
-        printf("  If 'type' is 'allu'), does the equivalent of:\n");
-	printf("  'comp', 'alias', 'sigu', 'netla', 'param', 'unconnectedinpins' and 'thread'.\n\n");
         printf("  If 'type' is omitted (or type is 'all'), does the equivalent of:\n");
 	printf("  'comp', 'alias', 'sigu', 'netla', 'param', and 'thread'.\n\n");
         printf("  See the man page ($man halcmd) for save option details\n");
